import pyautogui as p
import random as r
import time as t


"""
为了让右边的警示消失，改了好多语法和习惯。
0.0.4版将”锁定“函数的递归改为循环
"""


def suo_ding(name, region=(0, 0, 1920, 1080), confidence=0.7):  # 锁定目标图片并捕捉（点击），区域默认全屏。当函数后有注释时，开头空两行。
    f = False
    while True:
        location = p.locateOnScreen(name, region=region, confidence=confidence, grayscale=True)
        # confidence像素差异、grayscale灰度，返回一个元组。
        if location:
            f = True
            x1, y1, w, h = location  # 图片左上角的坐标，图片的宽、高。
            x2 = x1+w
            y2 = y1+h  # 计算得到图片右下角的坐标。
            X = r.randint(int(x1 + 0.1 * (x2 - x1)), int(x2 - 0.1 * (x2 - x1)))  # 将坐标区域向图片中心靠近，即图片边缘区域不点击。
            Y = r.randint(int(y1 + 0.1 * (y2 - y1)), int(y2 - 0.1 * (y2 - y1)))  # 获取随机位置X,Y。
            bu_zhuo(X, Y)
        else:
            break
    if f:
        return True
    else:
        return False


def bu_zhuo(x, y):
    L = ['p.easeInQuad', 'p.easeOutQuad', 'p.easeInOutQuad', 'p.easeInBounce', 'p.easeInElastic']  # 鼠标的5种移动方式。
    p.moveTo(x, y, 0.1, eval(L[r.randint(0, 4)]))  # 第3个参数，默认最小移动时间是0.1s。randint(0,4)取0到4整数。
    p.click(button='left')
    t.sleep(0.01)
    p.click(button='left')  # 防止点击无反应，补点一下。





"""
0.0.2版默认使用网易邮箱发送邮件，默认了发件人和收件人。
0.0.3版，补充了邮件日期，修改了部分邮件默认内容。
0.0.4版无变化
"""


import smtplib
from email.mime.text import MIMEText  # 负责构造文本。
from email.mime.image import MIMEImage  # 负责构造图片。
from email.mime.multipart import MIMEMultipart  # 负责将多个对象集合起来。
from email.header import Header
from email.utils import parseaddr, formataddr  # 美化收发件人格式，使之可以显示收发件人昵称。
import time


def format_addr(name_email):  # 将带昵称的邮件地址设置成符合邮件发送的格式
    name, addr = parseaddr(name_email)  # name昵称，addr是纯Email地址。
    e = formataddr((Header(name, 'utf-8').encode(), addr))  # formataddr函数将name和addr转换成标准Email地址格式
    return e


"""由于收件人默认为一个，‘处理多个收件人’功能暂时取消"""
# def receiver_names(mail_receivers):  # 处理多个收件人
#     txt=''
#     for i in range(0, len(mail_receivers)):
#         txt+="receiver_" + str(i+1) + "_name<" + mail_receivers[i] + '>,'
#     return txt[:-1]


def xie_you_jian(subject_content="在下肝阴阳师遇阻，速来相助！！！",  # 邮件主题
                 body_content='我反正处理不了了，你自己看着办吧~',  # 邮件正文内容
                 tu_pian='',
                 from_='肝帝_李茂仍',
                 mail_sender="13736200754@163.com",
                 to_='摸鱼仔',
                 mail_receivers="2324412934@qq.com"):
    # 默认了发件人和收件人
    message = MIMEMultipart("related")
    # 构造一个MIMEMultipart对象代表邮件本身。related 表示使用内嵌资源的形式将邮件发送给对方
    ''''''
    message["From"] = format_addr(from_ +"<"+ mail_sender + ">")  # 设置发送者，注意严格遵守格式
    message["To"] = format_addr(to_ +"<" + mail_receivers + ">")  # 多个收件人功能暂时取消receiver_names(mail_receivers)
    message["Subject"] = Header(subject_content, 'utf-8')  # 设置邮件主题
    message['date'] = time.strftime("%a,%d %b %Y %H:%M:%S %z")  # 设置邮件时间
    ''''''
    message_text = MIMEText(body_content, "plain", "utf-8")  # 构造文本,参数1：正文内容，参数2：文本格式，参数3：编码方式
    message.attach(message_text)  # 向MIMEMultipart对象中添加文本对象
    ''''''
    if tu_pian !='':
        image_data = open(tu_pian, 'rb')  # 二进制读取图片
        message_image = MIMEImage(image_data.read())  # 设置读取获取的二进制数据
        message_image['Content-Disposition']='attachment; filename="'+tu_pian+'"'
        image_data.close()  # 关闭刚才打开的文件
        message.attach(message_image)  # 添加图片文件到邮件信息中去
    ''''''
    return message


def fa_song_you_jian(message, mail_license,
                     mail_host="smtp.163.com",
                     mail_sender="13736200754@163.com",
                     mail_receivers="2324412934@qq.com"):  # 收件人不能设定为列表，列表可变，容易出错。
    # 除了邮件、邮箱授权码是输入，其余都是默认值。
    try:
        stp = smtplib.SMTP()  # 创建SMTP对象
        stp.connect(mail_host, 25)  # 设置发件人邮箱的域名和端口，端口地址为25
        # stp.set_debuglevel(1)  # set_debuglevel(1)可以打印出和SMTP服务器交互的所有信息
        stp.login(mail_sender, mail_license)  # 登录邮箱。参数1：邮箱地址，参数2：邮箱授权码
        stp.sendmail(mail_sender, mail_receivers, message.as_string())
        # 发送邮件。参数1：发件人邮箱地址，参数2：收件人邮箱地址，参数3：把邮件内容格式改为str
        print("邮件发送成功~")
        stp.quit()  # 关闭SMTP对象
    except Exception as e:
        """被Pycharm提示的原因是没有指定错误，except的范围太广了。"""
        print('邮件发送失败！------'+str(e))





"""常用功能
0.0.2版：
①将数字转换为年月日时分秒格式。
②使系统发出指定次数、指定音量（整十）的提示音。
0.0.3版：
②设定默认音量为100。
0.0.4版无变化。
"""


def shijian(t):  # 输入秒
    l1 = ['秒', '分钟', '小时', '天', '月', '年']
    l2 = [1, 60, 60, 24, 30, 365]  # 1是用来占位置来满足下面的range(1, xxx)的。
    time_ = '{:.0f}'.format(t % 60) + l1[0]
    for i in range(1, len(l1)):
        t=t//l2[i]
        if t != 0:
            time_ = '{:.0f}'.format(t % 60) + l1[i] + time_
        else:
            break
    return time_


def ding(n, loud=100):  # 发出’登登登‘的声音。输入次数、音量（整十）。
    import time
    from ctypes import cast, POINTER
    from comtypes import CLSCTX_ALL
    from pycaw.pycaw import AudioUtilities, IAudioEndpointVolume
    ''''''
    L = {0: -65.25, 10: -33.24, 20: -23.65, 30: -17.82, 40: -13.62, 50: -10.33,
         60: -7.63, 70: -5.33, 80: -3.34, 90: -1.58, 100: 0.0}
    """被Pycharm提示的原因是应避免使用字符’l、O、I‘来作为变量名，因为这些字符容易使人与数字1，0混淆。"""
    ''''''
    devices = AudioUtilities.GetSpeakers()
    interface = devices.Activate(IAudioEndpointVolume._iid_, CLSCTX_ALL, None)
    volume = cast(interface, POINTER(IAudioEndpointVolume))
    '''被Pycharm提示了，但是我实力不够，无法消除提示，凑合用吧。'''
    ''''''
    vl = volume.GetMasterVolumeLevel()  # 获取当前音量值，0.0代表最大，-65.25代表最小。
    # vr = volume.GetVolumeRange()  # 获取音量范围，我的电脑经测试是(-65.25, 0.0, 0.03125)，第一个代表最小值，第二个代表最大值。
    ''''''
    volume.SetMasterVolumeLevel(L[loud], None)  # 改变音量, 比如-13.6代表音量是40，0.0代表音量是100。
    for i in range(n):
        print('\a', end='')
        time.sleep(1.5)
    ''''''
    volume.SetMasterVolumeLevel(vl, None)  # 恢复原音量。



import setuptools

setuptools.setup(
    name="LiMaoreng",  # 库的名字
    version="0.0.4",  # 库的版本号，后续更新的时候只需要改版本号就行了
    author="李茂仍",
    author_email="2324412934@qq.com",
    description="""李茂仍的常用Python小功能。
    0.0.1版为测试版，无具体功能。
    0.0.2版提供了李茂仍常用的简单脚本功能。
    0.0.3版修复了部分错误
    0.0.4版移除了“锁定”函数的递归，改为循环""",  # 介绍
    long_description_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    install_requires=['pyautogui', "smtplib", "email", "pycaw"],  # 用户安装后，系统会自动安装第三方库
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License ",
        "Operating System :: OS Independent",
    ],
)
'''
python setup.py sdist
twine upload dist/*
LiMaoreng
密码'''
